#!/usr/bin/env python
# Copyright (c) 2016, Universal Robots A/S,
# All rights reserved.
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#    * Redistributions of source code must retain the above copyright
#      notice, this list of conditions and the following disclaimer.
#    * Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#    * Neither the name of the Universal Robots A/S nor the names of its
#      contributors may be used to endorse or promote products derived
#      from this software without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL UNIVERSAL ROBOTS A/S BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

import sys
import logging

from rtde.rtde import RTDE
from rtde.rtde_config import ConfigFile

import socket

SENSOR_HOST = '127.0.0.1'
ROBOT_HOST = '127.0.0.1'
ROBOT_PORT = 30004
config_filename = 'force_injection.xml'

RTDE_PROTOCOL_VERSION = 1

keep_running = True

logging.getLogger().setLevel(logging.WARNING)

rtde_client = RTDE(ROBOT_HOST, ROBOT_PORT)
rtde_client.connect()

# get controller version
rtde_client.get_controller_version()

# set protocol version
if not rtde_client.negotiate_protocol_version(RTDE_PROTOCOL_VERSION):
    sys.exit()

#########################
# setup recipes
recipe_config = ConfigFile(config_filename)

sensor_names, sensor_types = recipe_config.get_recipe('sensor')
sensor_data = rtde_client.send_input_setup(sensor_names, sensor_types)
sensor_data.external_force_torque = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0]

##################################


#sensor = FTSensorTCP(SENSOR_HOST)
#sensor.connect()

ft_names, ft_types = recipe_config.get_recipe('robot_force_torque')
ft_data = rtde_client.send_output_setup(ft_names, ft_types)
#########################

#start data synchronization
if not rtde_client.send_start():
    sys.exit()

# control loop
while keep_running:
    # receive the current state

    sensor_data.external_force_torque = [0, 0, 0, 0, 0, 0]
    rtde_client.send(sensor_data)

    state = rtde_client.receive()

    if state is None:
        break;

rtde_client.send_pause()

rtde_client.disconnect()
